@@ -217,7 +217,7 @@ if (modele %in% c("pls-glm-polr")) {
 YwotNA <- as.factor(YwotNA)
 if (!pvals.expli) {
 XXwotNA[!XXNA] <- NA
-library(MASS)
+requireNamespace("MASS")
 tts <- res$tt
 for (jj in 1:(res$nc)) {
     tempww[jj] <- -1*MASS::polr(YwotNA~cbind(tts,XXwotNA[,jj]),na.action=na.exclude,method=method)$coef[kk]
@@ -226,7 +226,7 @@ XXwotNA[!XXNA] <- 0
 rm(jj,tts)}
 else {
 XXwotNA[!XXNA] <- NA
-library(MASS)
+requireNamespace("MASS")
 tts <- res$tt
 tempvalpvalstep <- rep(0,res$nc)
 temppvalstep <- rep(0,res$nc)
